@@ -1,7 +1,7 @@
 """ Widgets for reusing parts of the JupyterLab interface
 """
 
-from ._version import __version__
+from ._version import __version__, module_name
 from .widget_dock import DockBox, DockPop
 from .widget_editor import Editor, EditorConfig, EditorModeInfo
 from .widget_markdown import Markdown
@@ -17,3 +17,7 @@ __all__ = [
     "EditorConfig",
     "EditorModeInfo",
 ]
+
+
+def _jupyter_labextension_paths():
+    return [{"src": "labextension", "dest": module_name}]
